############# Packages ##############

### Hinweis: Wrapper aufrufen mit
### freewrap ProTeXtSetup.tcl -f combobox.txt

package require registry 1.0
lappend auto_path combobox-2.3; # Ensure our application can find the files
lappend auto_path protext/combobox-2.3; # no matter if they exist on CD or DVD
package require combobox 2.3
catch {namespace import combobox::*}

############ Graphics ##############

#### Tk-Oberflche

wm title . "ProTeXt - Installation"
wm geometry . 340x180+50+50

### Generierung von 3 Frames, quasi als Container fr den Fensteraufbau.
### Als da wren...

frame .languageliste -relief groove -borderwidth 4
frame .komponentenliste -relief groove -borderwidth 4
frame .buttonzeile
pack .languageliste .komponentenliste -anchor w -side top -fill both -expand 1 -padx 1m -pady 1m
pack .buttonzeile -side bottom -anchor e

### ... Sprachauswahl ...
label .languageliste.titel \
    -font "*-Arial-*--*-12-*" \
    -text "Select language:"

combobox .languageliste.auswahl \
        -borderwidth 1 \
        -font "*-Arial-*--*-14-*" \
        -textvariable language \
        -editable false \
        -highlightthickness 1 \
        -command {transferLanguage}

### sprachenabhngig
##.languageliste.auswahl list insert end "English" "Deutsch" "Espag\u00F1ol" "Fran\u00E7ais" "Italiano" "Polski"
.languageliste.auswahl list insert end "English" "Deutsch" "Fran\u00E7ais" "Italiano"
pack .languageliste.titel .languageliste.auswahl -side top -anchor w -pady 1m

## Setzen der Defaults
set language "English"

### ... Komponenten (ProTeXt, Ctan, TeXLive) ...
label .komponentenliste.titel \
    -font "*-Arial-*--*-12-*" \
    -text "Open:"
radiobutton .komponentenliste.protext \
    -font "*-Arial-*--*-14-*" \
    -text ProTeXt -variable komponente -value pt
radiobutton .komponentenliste.ctan \
    -font "*-Arial-*--*-14-*" \
    -text "CTAN" -variable komponente -value ct
radiobutton .komponentenliste.texlive \
    -font "*-Arial-*--*-14-*" \
    -text "TeX Live" -variable komponente -value tl
radiobutton .komponentenliste.context \
    -font "*-Arial-*--*-14-*" \
    -text "ConTeXt" -variable komponente -value cnt
set komponente "pt"
pack .komponentenliste.titel -side top -anchor w
pack .komponentenliste.protext .komponentenliste.ctan .komponentenliste.texlive .komponentenliste.context -side left

### ... und die Knpfe zur Steuerung.
button .buttonzeile.cancel -text "Close" -command exit
## "Next >" fhrt die Prozedur doMain aus, und bergibt das Krzel der
## ausgewhlten Komponente (pt, ct, tl)
button .buttonzeile.weiter -text "Next >" -command {doMain $komponente}
pack .buttonzeile.weiter .buttonzeile.cancel -side right -padx 1m -pady 1m

### Bindings
bind .buttonzeile.cancel <Return> {exit}
bind .buttonzeile.weiter <Return> {doMain $komponente}

############# Functions #############

### getAcroPath ###
proc getAcroPath {} {
### sucht nach Adobe Reader, bzw. Acrobat und gibt den vollen Executable-Path zurck
set acp "NULL";

## Try to get Adobe Reader...
catch {set acp [registry get "HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\App Paths\\AcroRd32.exe" ""]}

## ...or Acrobat (Professional?) if this fails...
if { [string compare $acp "NULL"] == 0 } {

    catch {set acp [registry get "HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\App Paths\\Acrobat.exe" ""]}
}

## ...return whats have been found (at least NULL...)
return $acp
}

### overAndOut ###
proc overAndOut {info_message} {
### erzeugt ein Error-PopUp-Fenster mit variablem Inhalt. Die Message wird durch
### info_message transportiert

toplevel .protextinfo
wm title .protextinfo "ProTeXt - Error"
wm geometry .protextinfo +350+350

frame .protextinfo.display  -borderwidth 4
frame .protextinfo.button
pack .protextinfo.display -side top -fill x -anchor w -padx 1m -pady 1m
pack .protextinfo.button -side bottom

frame .protextinfo.display.left
frame .protextinfo.display.right
pack .protextinfo.display.left -side left -padx 3m
pack .protextinfo.display.right -side right -fill x -anchor w -ipadx 1m -ipady 1m

message .protextinfo.display.right.msg \
    -font "*-Arial-*--*-14-*" \
    -justify left -text $info_message \
    -width 80m
button .protextinfo.button.ui_ok -text OK -command {destroy .protextinfo}

label .protextinfo.display.left.ui_bitmap -bitmap questhead

pack .protextinfo.display.right.msg -side right
pack .protextinfo.display.left.ui_bitmap -side left
pack .protextinfo.button.ui_ok

bell
}

### setUILanguage ###
### sprachenabhngig
proc setUILanguage {lang} {
### bernimmt die ausgewhlte Oberflchensprache ($lang) und besetzt Label, Knpfe
### und Fehlermeldungen adquat. Darberhinaus wird der Pfad zum bentigten ProTeXt-Doc
### gesetzt

global infomessage instskript fatalerror workdir

## Set the right information, depending on selected language.

if { [string compare $lang "de"] == 0 } {

    set fatalerror "Ein (unerwarteter) Fehler ist aufgetreten!\n\n"
    set fatalerror [format "%s%s" $fatalerror "Kontrollieren Sie ob der Adobe Reader korrekt \
        installiert ist, und starten Sie diese Installation erneut."]

    set infomessage "Fr die Installation wird mindestens der Adobe Reader bentigt.\n\n"
    set infomessage [format "%s%s" $infomessage "Den Adobe Reader bekommen Sie kostenlos unter:\n\n"]
    set infomessage [format "%s%s" $infomessage "http://www.adobe.de"]

    set instskript "$workdir\\Install\\protext-install-de.pdf"

    .languageliste.titel configure -text "Gewnschte Installationssprache:"
    .komponentenliste.titel configure -text "Starte:"
    .buttonzeile.cancel configure -text "Abbrechen"
    .buttonzeile.weiter configure -text "Weiter >"

} elseif { [string compare $lang "es"] == 0 } {

    set fatalerror "Ha ocurrido un error inesperado!\n\n"
    set fatalerror [format "%s%s" $fatalerror "Asegrese que Adobe Reader est \
        instalado correctamente e intente de nuevo la instalacin."]

    set infomessage "Esta instalacin necesita como mnimo Adobe Reader o Acrobat.\n\n"
    set infomessage [format "%s%s" $infomessage "Para obtener una copia gratuita de Adobe Reader vaya a:\n\n"]
    set infomessage [format "%s%s" $infomessage "http://www.adobe.es"]

    set instskript "$workdir\\Install\\protext-install-es.pdf"

    .languageliste.titel configure -text "Seleccione el idioma:"
    .komponentenliste.titel configure -text "Abrir:"
    .buttonzeile.cancel configure -text "Cerrar"
    .buttonzeile.weiter configure -text "Despus >"

} elseif { [string compare $lang "fr"] == 0 } {

    set fatalerror "Une erreur inattendue est apparue!\n\n"
    set fatalerror [format "%s%s" $fatalerror "contrlez si le Adobe lecteur est \
        install correctement, et vous commencez cette installation de nouveau."]

    set infomessage "Pour l'installation, le Adobe lecteur est ncessaire au moins.\n\n"
    set infomessage [format "%s%s" $infomessage "Des lecteurs obtiennent gratuitement dessous les Adobe vous:\n\n"]
    set infomessage [format "%s%s" $infomessage "http://www.adobe.fr"]

    set instskript "$workdir\\Install\\protext-install-fr.pdf"

    .languageliste.titel configure -text "Langue d'installation souhaite:"
    .komponentenliste.titel configure -text "Ouvre:"
    .buttonzeile.cancel configure -text "Annulation"
    .buttonzeile.weiter configure -text "Plus >"

} elseif { [string compare $lang "pl"] == 0 } {

    set fatalerror "Niespodziewany b\u0142\u0105d!\n\n"
    set fatalerror [format "%s%s" $fatalerror "Upewnij si\u0119, czy zaistalowa\u0142e\u015B prawid\u0142owo \
        Adobe Reader i uruchom ponownie ten program instalacyjny."]

    set infomessage "Ta instalacja wymaga posiadania Adobe Reader lub Acrobat.\n\n"
    set infomessage [format "%s%s" $infomessage "Darmow\u0105 kopi\u0119 programu Adobe Reader znajdziesz na:\n\n"]
    set infomessage [format "%s%s" $infomessage "http://www.adobe.com"]

    set instskript "$workdir\\Install\\protext-install-pl.pdf"

    .languageliste.titel configure -text "Wybierz j\u0119zyk:"
    .komponentenliste.titel configure -text "Otwrz:"
    .buttonzeile.cancel configure -text "Anuluj"
    .buttonzeile.weiter configure -text "Dalej >"

} elseif { [string compare $lang "it"] == 0 } {

    set fatalerror "Un errore inatteso  apparso!\n\n"
    set fatalerror [format "%s%s" $fatalerror "Controllate se il Adobe Reader  installato \
        correttamente, e cominciate quest'impianto nuovamente."]

    set infomessage "Per l'impianto, il Adobe lettore  necessario almeno.\n\n"
    set infomessage [format "%s%s" $infomessage "Per una copia libera del Reader dell'adobe vada a:\n\n"]
    set infomessage [format "%s%s" $infomessage "http://www.adobe.it"]

    set instskript "$workdir\\Install\\protext-install-it.pdf"

    .languageliste.titel configure -text "Selezioni la lingua:"
    .komponentenliste.titel configure -text "Apre:"
    .buttonzeile.cancel configure -text "Annullamento"
    .buttonzeile.weiter configure -text "Pi >"

} else {

    set fatalerror "An (unexpected) Error happened!\n\n"
    set fatalerror [format "%s%s" $fatalerror "Make sure that Adobe Reader was \
        installed properly and retry this installation."]

    set infomessage "This installation requires at least Adobe Reader or Acrobat to complete.\n\n"
    set infomessage [format "%s%s" $infomessage "For a free copy of Adobe Reader go to:\n\n"]
    set infomessage [format "%s%s" $infomessage "http://www.adobe.com"]

    set instskript "$workdir\\Install\\protext-install-en.pdf"

    .languageliste.titel configure -text "Select language:"
    .komponentenliste.titel configure -text "Open:"
    .buttonzeile.cancel configure -text "Close"
    .buttonzeile.weiter configure -text "Next >"

}

return
}

### locateRootDir ###
proc locateRootDir {} {
### stellt fest, in welchem Verzeichnis sich autorun.inf befindet und damit Root-Verzeichnis
### ist(alle anderen Pfade sind im Normalfall davon abhngig).
### Danach ist ein bisschen Nachbearbeitung ntig:

## Trailing-/ werden entfernt...
set rd [string trimright [pwd] /]
## ...und Verzeichnistrennzeichen werden in die Form gebracht, die Bill Gates sich
## gewnscht hat.
regsub -all / $rd \\ rd

return $rd
}

### locateWorkDir ###
proc locateWorkDir {rd} {
### bekommt das ermittelte Root-Directory bergeben und ermittelt das Arbeitsverzeichnis
### von ProTeXt (wahlweise auf DVD oder CD)

if {[file exists $rd\\protext] == 0} {

    set wd $rd; ## CD: ProTeXtDir = RootDir

} else {

    set wd $rd\\protext; ## DVD: ProTeXtDir = RootDir + \protext

}

return $wd;
}

### locateAdditionalContentDir ###
proc locateAdditionalContentDir {rd wd} {
### lokalisiert wo sich auf der DVD Verzeichnisse fr CTAN, TeXLive und
### ConTeXt verstecken knnten

if {[string compare $rd $wd] == 0} {

    set acd $rd\\..; ## Setup.exe befindet sich im "RootDir"

} else {

    set acd $rd; ## Setup.exe wurde ber protext/Setup.exe gestartet (DVD)

}

return $acd;
}


### checkComponents ###
proc checkComponents {} {
### berprft ob Ctan und/oder TeXLive auf dem Datentrger existieren und klemmt
### im Negativfall die Auswahlmglichkeit im Fenster ab

global adcondir

if {[file exists $adcondir\\ctan] == 0} {

    .komponentenliste.ctan configure -state disabled

}

if {[file exists $adcondir\\texlive] == 0} {

    .komponentenliste.texlive configure -state disabled

}

if {[file exists $adcondir\\context] == 0} {

    .komponentenliste.context configure -state disabled

}

}

### doProTeXt ###
proc doProTeXt {} {
### enthlt alle Anweisungen die fr ProTeXt durchgefhrt werden mssen

global infomessage instskript fatalerror instlang

set AcroPath "NULL"

set AcroPath [getAcroPath]

if { [string compare $AcroPath "NULL"] == 0 } {

## NO Acrobat has been found, so create a message, howl and wait until the popup
## will be confirmed.
    overAndOut $infomessage
    tkwait window .protextinfo

} else {

## Start the found Acrobat
    set retcode [catch {exec $AcroPath $instskript}]

# Acrobat 7 verabschiedet sich grundstzlich mit einem Retcode von 1
# Ob jemals andere Retcodes auftauchen knnen...

    if { $retcode > 1 } {
        overAndOut $fatalerror
        tkwait window .protextinfo
    }
}

}

### doCtan ###
proc doCtan {} {
### enthlt alle Anweisungen dir fr Ctan durchgefhrt weden mssen

global adcondir

catch {exec explorer.exe /n, /e, /root, $adcondir\\ctan}

}

### doTeXLive ###
proc doTeXLive {} {
### enthlt alle Anweisungen dir fr TeXLive durchgefhrt weden mssen

global adcondir

if {[file exists $adcondir\\texlive\\setuptl\\tlpmgui.exe] == 0} {

    catch {exec explorer.exe /n, /e, /root, $adcondir\\texlive}

} else {

    catch {exec $adcondir\\texlive\\setuptl\\tlpmgui.exe}

}
}

### doConTeXt ###
proc doConTeXt {} {
### enthlt alle Anweisungen dir fr ConTeXt durchgefhrt weden mssen

global adcondir

catch {exec explorer.exe /n, /e, /root, $adcondir\\context}

}

### doMain ###
proc doMain {activecomponent} {
### setzt so einiges in Gang

## Verstecken des Main-Fensters
wm withdraw .

## Start the action for the selected component...
switch $activecomponent {

    pt {doProTeXt}
    ct {doCtan}
    tl {doTeXLive}
    cnt {doConTeXt}
    default {doProTeXt}

}

### ...and let him make the rest alone.
exit
}

### transferLanguage ###
### sprachenabhngig
proc transferLanguage {window item} {

switch $item {

    English {setUILanguage "uk"}
    Deutsch {setUILanguage "de"}
    Espag\u00F1ol {setUILanguage "es"}
    Fran\u00E7ais {setUILanguage "fr"}
    Italiano {setUILanguage "it"}
    Polski  {setUILanguage "pl"}
    default {setUILanguage "uk"}

}

}

############# Globals ###############

set infomessage "";
set fatalerror "";
set instskript "";
set rootdir [locateRootDir];
set workdir [locateWorkDir $rootdir];
set adcondir [locateAdditionalContentDir $rootdir $workdir]

############# Main Program ##########

### Hide Freewrap's console window
console hide

### Determine which components are available
setUILanguage "uk"
checkComponents

### Focus wird default aufs Auswahlfeld gesetzt
focus -force .languageliste.auswahl

############# End of Main ###########
